@@ -77,6 +77,7 @@ public:
     void addAllele(Allele allele, bool mergeComplex = true,
                    int maxComplexGap = 0, bool boundIndels = false);
     bool fitHaplotype(int pos, int haplotypeLength, Allele*& aptr, bool allowPartials = false);
+    void clumpAlleles(bool mergeComplex = true, int maxComplexGap = 0, bool boundIndels = false);
 
 };
 
@@ -249,7 +250,7 @@ public:
     void removeNonOverlappingAlleles(vector<Allele*>& alleles,
                                      int haplotypeLength = 1,
                                      bool getAllAllelesInHaplotype = false);
-    void removePreviousAlleles(vector<Allele*>& alleles);
+    void removePreviousAlleles(vector<Allele*>& alleles, long int position);
     void removeFilteredAlleles(vector<Allele*>& alleles);
     void removeDuplicateAlleles(Samples& samples, map<string, vector<Allele*> >& alleleGroups,
                                 int allowedAlleleTypes, int haplotypeLength, Allele& refallele);
