@@ -19,6 +19,7 @@ class CNVMap {
 public:
     CNVMap(void) : defaultPloidy(2) { }
     void setDefaultPloidy(int defploidy);
+    void setSamplePloidy(const string& sample, int ploidy);
     bool load(string const& filename);
     int ploidy(string const& sample, string const& seq, long int position);
     void setPloidy(string const& sample, string const& seq, long int start, long int end, int ploidy);
@@ -27,6 +28,7 @@ private:
     // note: this map is stored as 0-based, end position exclusive
     SampleSeqCNVMap sampleSeqCNV;
     int defaultPloidy;
+    map<string, int> samplePloidy;
 
 };
 
