@@ -19,7 +19,9 @@
 #include <stdlib.h>
 
 // private libraries
+#ifdef HAVE_BAMTOOLS
 #include "api/BamReader.h"
+#endif
 #include "Fasta.h"
 #include "TryCatch.h"
 #include "Parameters.h"
@@ -40,24 +42,7 @@
 #include "Bias.h"
 #include "Contamination.h"
 #include "NonCall.h"
-
-
-// local helper debugging macros to improve code readability
-#define DEBUG(msg) \
-     if (parameters.debug) { cerr << msg << endl; }
-
-// lower-priority messages
-#ifdef VERBOSE_DEBUG
-#define DEBUG2(msg) \
-    if (parameters.debug2) { cerr << msg << endl; }
-#else
-#define DEBUG2(msg)
-#endif
-
-// must-see error messages
-#define ERROR(msg) \
-    cerr << msg << endl;
-
+#include "Logging.h"
 
 using namespace std;
 
@@ -149,10 +134,10 @@ int main (int argc, char *argv[]) {
             nonCalls.clear();
         }
 
-        // don't process non-ATGC's in the reference
+        // don't process non-ATGCN's in the reference
         string cb = parser->currentReferenceBaseString();
-        if (cb != "A" && cb != "T" && cb != "C" && cb != "G") {
-            DEBUG2("current reference base is N");
+        if (cb != "A" && cb != "T" && cb != "C" && cb != "G" && cb != "N") {
+            DEBUG2("current reference base is not in { A T G C N }");
             continue;
         }
 
@@ -305,7 +290,8 @@ int main (int argc, char *argv[]) {
         string referenceBase = parser->currentReferenceHaplotype();
 
 
-        /* for debugging
+        // for debugging
+        /*
         for (Samples::iterator s = samples.begin(); s != samples.end(); ++s) {
             string sampleName = s->first;
             Sample& sample = s->second;
